pub struct Launcher { /* private fields */ }Expand description
Launcher for asynchronous dispatch of filters through the Self::launch() method.
This type is intended to be injected in configuration function.
Implementations
Sourceimpl Launcher
impl Launcher
Sourcepub async fn launch<F, I>(self, filter: F) -> Result<(), LaunchError>where
F: IntoHandler<FilterContext, I, Output = ()>,
pub async fn launch<F, I>(self, filter: F) -> Result<(), LaunchError>where
F: IntoHandler<FilterContext, I, Output = ()>,
Launches a filter to handle incoming concurrent requests.
This method ends when no more requests can be handled.
filter- The filter to be launched.
Errors
This method will return an error in the following situation, but is not limited to just this cases:
- a
filtercan not be injected with extractible arguments.