pub struct HttpClient { /* private fields */ }Expand description
An asynchronous HTTP client to make Requests with.
Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub fn request<'a>(
&'a self,
service: &'a Service,
) -> RequestBuilder<'a, DefaultResponseExtractor>
pub fn request<'a>( &'a self, service: &'a Service, ) -> RequestBuilder<'a, DefaultResponseExtractor>
Creates a request that will forward the whole response to the caller.
Note: If you want to avoid reading body buffers in certain situations see the extract_with method.